from typing import List, Tuple

def add(a: int, b: int) -> int:
    """
    A method to add two numbers

    Parameters:
     - a (int): the first number
     - b (int): the second number

    Returns: sum of a and b
    """
    return a + b

def subtract(a: int, b: int) -> int:
    return a - b

def divide(a: int, b: int) -> float:
    return a / b

def multiply(a: int, b: int) -> int:
    return a * b